==> ipodslave_0.6.3.orig.tar.gz: ipodslave-0.6.3/src/ipodutility.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Michael Schulze                                 *
 *   mike.s@genion.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef IPODUTILITY_H
#define IPODUTILITY_H

#include <qstring.h>

#include <kurl.h>

/**
@author Michael Schulze
*/
class IPodUtility{
public:
    virtual const QString& getName() = 0;
    virtual const QString& getDefaultMimeType() = 0;
    virtual void handleRequest( const KURL& request, QByteArray& response, QString& mimeType) = 0;
};

#endif

==> ipodslave_0.7.3.orig.tar.gz: ipodslave-0.7.3/src/ipodutility.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Michael Schulze                                 *
 *   mike.s@genion.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef IPODUTILITY_H
#define IPODUTILITY_H

#include <qstring.h>
#include "ipod.h"
#include <kurl.h>

/**
@author Michael Schulze
*/
class IPodUtility{
public:
    virtual const QString& getName() = 0;
    virtual const QString& getDefaultMimeType() = 0;
    virtual void handleRequest( IPod& ipod, const KURL& request, QByteArray& response, QString& mimeType) = 0;
};

#endif
